@@ -1,4 +1,4 @@
-/* Copyright (c) 2008-2021 the MRtrix3 contributors.
+/* Copyright (c) 2008-2022 the MRtrix3 contributors.
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -36,8 +36,8 @@ namespace MR
        *  phase-encoding direction between a 3-vector (e.g.
        *  [0 1 0] ) and a NIfTI axis identifier (e.g. 'i-')
        */
-    std::string    dir2id (const Eigen::Vector3&);
-    Eigen::Vector3 id2dir (const std::string&);
+    std::string    dir2id (const Eigen::Vector3d&);
+    Eigen::Vector3d id2dir (const std::string&);
 
 
 
