@@ -1,4 +1,4 @@
-# Copyright (c) 2008-2021 the MRtrix3 contributors.
+# Copyright (c) 2008-2022 the MRtrix3 contributors.
 #
 # This Source Code Form is subject to the terms of the Mozilla Public
 # License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -13,6 +13,9 @@
 #
 # For more details, see http://www.mrtrix.org/.
 
+# note: deal with these warnings properly when we drop support for Python 2:
+# pylint: disable=unspecified-encoding,consider-using-f-string
+
 import argparse, inspect, math, os, random, shlex, shutil, signal, string, subprocess, sys, textwrap, time
 from mrtrix3 import ANSI, CONFIG, MRtrixError, setup_ansi
 from mrtrix3 import utils # Needed at global level
@@ -56,7 +59,7 @@ CMDLINE = None
 
 
 _DEFAULT_COPYRIGHT = \
-'''Copyright (c) 2008-2021 the MRtrix3 contributors.
+'''Copyright (c) 2008-2022 the MRtrix3 contributors.
 
 This Source Code Form is subject to the terms of the Mozilla Public
 License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -108,7 +111,7 @@ else:
 # , rather than executing this function directly
 def _execute(module): #pylint: disable=unused-variable
   from mrtrix3 import run #pylint: disable=import-outside-toplevel
-  global ARGS, CMDLINE, CONTINUE_OPTION, DO_CLEANUP, EXEC_NAME, FORCE_OVERWRITE, NUM_THREADS, SCRATCH_DIR, VERBOSITY, WORKING_DIR
+  global ARGS, CMDLINE, CONTINUE_OPTION, DO_CLEANUP, FORCE_OVERWRITE, NUM_THREADS, SCRATCH_DIR, VERBOSITY
 
   # Set up signal handlers
   for sig in _SIGNALS:
@@ -268,7 +271,6 @@ def _execute(module): #pylint: disable=unused-variable
 
 
 def check_output_path(item): #pylint: disable=unused-variable
-  global ARGS, FORCE_OVERWRITE, WORKING_DIR
   if not item:
     return
   abspath = os.path.abspath(os.path.join(WORKING_DIR, item))
@@ -287,7 +289,7 @@ def check_output_path(item): #pylint: disable=unused-variable
 
 def make_scratch_dir(): #pylint: disable=unused-variable
   from mrtrix3 import run #pylint: disable=import-outside-toplevel
-  global ARGS, CONTINUE_OPTION, EXEC_NAME, SCRATCH_DIR, WORKING_DIR
+  global SCRATCH_DIR
   if CONTINUE_OPTION:
     debug('Skipping scratch directory creation due to use of -continue option')
     return
@@ -309,7 +311,8 @@ def make_scratch_dir(): #pylint: disable=unused-variable
     outfile.write(WORKING_DIR + '\n')
   with open(os.path.join(SCRATCH_DIR, 'command.txt'), 'w') as outfile:
     outfile.write(' '.join(sys.argv) + '\n')
-  open(os.path.join(SCRATCH_DIR, 'log.txt'), 'w').close()
+  with open(os.path.join(SCRATCH_DIR, 'log.txt'), 'w'):
+    pass
   # Also use this scratch directory for any piped images within run.command() calls,
   #   and for keeping a log of executed commands / functions
   run.shared.set_scratch_dir(SCRATCH_DIR)
@@ -317,7 +320,6 @@ def make_scratch_dir(): #pylint: disable=unused-variable
 
 
 def goto_scratch_dir(): #pylint: disable=unused-variable
-  global SCRATCH_DIR
   if not SCRATCH_DIR:
     raise Exception('No scratch directory location set')
   if VERBOSITY:
@@ -331,7 +333,6 @@ def goto_scratch_dir(): #pylint: disable=unused-variable
 #   all intermediates, the resource will be retained; if not, it will be deleted (in particular
 #   to dynamically free up storage space used by the script).
 def cleanup(items): #pylint: disable=unused-variable
-  global DO_CLEANUP, VERBOSITY
   if not DO_CLEANUP:
     return
   if isinstance(items, list):
@@ -376,12 +377,10 @@ def cleanup(items): #pylint: disable=unused-variable
 
 # A set of functions and variables for printing various information at the command-line.
 def console(text): #pylint: disable=unused-variable
-  global VERBOSITY
   if VERBOSITY:
     sys.stderr.write(EXEC_NAME + ': ' + ANSI.console + text + ANSI.clear + '\n')
 
 def debug(text): #pylint: disable=unused-variable
-  global EXEC_NAME, VERBOSITY
   if VERBOSITY <= 2:
     return
   outer_frames = inspect.getouterframes(inspect.currentframe())
@@ -446,7 +445,6 @@ def var(*variables): #pylint: disable=unused-variable
     del calling_frame
 
 def warn(text): #pylint: disable=unused-variable
-  global EXEC_NAME
   sys.stderr.write(EXEC_NAME + ': ' + ANSI.warn + '[WARNING] ' + text + ANSI.clear + '\n')
 
 
@@ -468,7 +466,7 @@ class ProgressBar(object): #pylint: disable=unused-variable
 
   def __init__(self, msg, target=0):
     from mrtrix3 import run #pylint: disable=import-outside-toplevel
-    global EXEC_NAME, VERBOSITY
+    global VERBOSITY
     if not (isinstance(msg, utils.STRING_TYPES) or callable(msg)):
       raise TypeError('app.ProgressBar must be constructed using either a string or a function')
     self.counter = 0
@@ -518,7 +516,7 @@ class ProgressBar(object): #pylint: disable=unused-variable
 
   def done(self, msg=None):
     from mrtrix3 import run #pylint: disable=import-outside-toplevel
-    global EXEC_NAME, VERBOSITY
+    global VERBOSITY
     self.iscomplete = True
     if msg is not None:
       self.message = msg
@@ -538,7 +536,6 @@ class ProgressBar(object): #pylint: disable=unused-variable
 
 
   def _update(self):
-    global EXEC_NAME
     assert not self.iscomplete
     if not self.orig_verbosity:
       return
@@ -570,7 +567,6 @@ class Parser(argparse.ArgumentParser):
 
   # pylint: disable=protected-access
   def __init__(self, *args_in, **kwargs_in):
-    global _DEFAULT_COPYRIGHT
     self._author = None
     self._citation_list = [ ]
     self._copyright = _DEFAULT_COPYRIGHT
@@ -658,7 +654,6 @@ class Parser(argparse.ArgumentParser):
   def print_citation_warning(self):
     # If a subparser has been invoked, the subparser's function should instead be called,
     #   since it might have had additional citations appended
-    global ARGS
     if self._subparsers:
       subparser = getattr(ARGS, self._subparsers._group_actions[0].dest)
       for alg in self._subparsers._group_actions[0].choices:
@@ -675,7 +670,7 @@ class Parser(argparse.ArgumentParser):
       console('')
 
   # Overloads argparse.ArgumentParser function to give a better error message on failed parsing
-  def error(self, text):
+  def error(self, message):
     for entry in sys.argv:
       if '-help'.startswith(entry):
         self.print_help()
@@ -689,7 +684,7 @@ class Parser(argparse.ArgumentParser):
         if alg == sys.argv[1]:
           usage = self._subparsers._group_actions[0].choices[alg].format_usage()
           continue
-    sys.stderr.write('\nError: %s\n' % text)
+    sys.stderr.write('\nError: %s\n' % message)
     sys.stderr.write('Usage: ' + usage + '\n')
     sys.stderr.write('       (Run ' + self.prog + ' -help for more information)\n\n')
     sys.stderr.flush()
@@ -820,7 +815,7 @@ class Parser(argparse.ArgumentParser):
         elif option.nargs:
           if isinstance(option.nargs, int):
             group_text += (' ' + option.dest.upper())*option.nargs
-          elif option.nargs == '+' or option.nargs == '*':
+          elif option.nargs in ('+', '*'):
             group_text += ' <space-separated list>'
           elif option.nargs == '?':
             group_text += ' <optional value>'
@@ -1092,7 +1087,7 @@ class Parser(argparse.ArgumentParser):
     sys.stdout.flush()
 
   def _get_ungrouped_options(self):
-    return next((group for group in self._action_groups if group.title == 'optional arguments'), None)
+    return next((group for group in self._action_groups if group.title in ( 'options', 'optional arguments') ), None)
 
   def _is_option_group(self, group):
     # * Don't display empty groups
@@ -1103,7 +1098,7 @@ class Parser(argparse.ArgumentParser):
            not (len(group._group_actions) == 1 and \
            isinstance(group._group_actions[0], argparse._SubParsersAction)) and \
            not group == self._positionals and \
-           group.title != 'optional arguments'
+           group.title not in ( 'options', 'optional arguments' )
 
 
 
@@ -1116,7 +1111,6 @@ def add_dwgrad_import_options(cmdline): #pylint: disable=unused-variable
   cmdline.flag_mutually_exclusive_options( [ 'grad', 'fslgrad' ] )
 def read_dwgrad_import_options(): #pylint: disable=unused-variable
   from mrtrix3 import path #pylint: disable=import-outside-toplevel
-  global ARGS
   assert ARGS
   if ARGS.grad:
     return ' -grad ' + path.from_user(ARGS.grad)
@@ -1131,7 +1125,6 @@ def add_dwgrad_export_options(cmdline): #pylint: disable=unused-variable
   cmdline.flag_mutually_exclusive_options( [ 'export_grad_mrtrix', 'export_grad_fsl' ] )
 def read_dwgrad_export_options(): #pylint: disable=unused-variable
   from mrtrix3 import path #pylint: disable=import-outside-toplevel
-  global ARGS
   assert ARGS
   if ARGS.export_grad_mrtrix:
     check_output_path(path.from_user(ARGS.export_grad_mrtrix, False))
@@ -1150,7 +1143,7 @@ def read_dwgrad_export_options(): #pylint: disable=unused-variable
 # Handler function for dealing with system signals
 def handler(signum, _frame):
   from mrtrix3 import run #pylint: disable=import-outside-toplevel
-  global _SIGNALS, EXEC_NAME, SCRATCH_DIR, WORKING_DIR
+  global SCRATCH_DIR
   # Terminate any child processes in the run module
   try:
     run.shared.terminate(signum)
@@ -1173,9 +1166,12 @@ def handler(signum, _frame):
   if os.getcwd() != WORKING_DIR:
     os.chdir(WORKING_DIR)
   if SCRATCH_DIR:
-    try:
-      shutil.rmtree(SCRATCH_DIR)
-    except OSError:
-      pass
-    SCRATCH_DIR = ''
+    if DO_CLEANUP:
+      try:
+        shutil.rmtree(SCRATCH_DIR)
+      except OSError:
+        pass
+      SCRATCH_DIR = ''
+    else:
+      sys.stderr.write(EXEC_NAME + ': ' + ANSI.console + 'Scratch directory retained; location: ' + SCRATCH_DIR + ANSI.clear + '\n')
   os._exit(signum) # pylint: disable=protected-access
