@@ -1,4 +1,4 @@
-/* Copyright (c) 2008-2021 the MRtrix3 contributors.
+/* Copyright (c) 2008-2022 the MRtrix3 contributors.
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -277,8 +277,8 @@ namespace MR {
 
 
           // Convenience functions for Directionally-Encoded Colour processing
-          Eigen::Vector3 get_dec ();
-          void           set_dec (const Eigen::Vector3&);
+          Eigen::Vector3d get_dec ();
+          void           set_dec (const Eigen::Vector3d&);
 
           // Convenience functions for Track Orientation Distribution processing
           void get_tod (      VoxelTOD::vector_type&);
@@ -458,10 +458,10 @@ namespace MR {
 
 
         template <typename value_type>
-          Eigen::Vector3 MapWriter<value_type>::get_dec ()
+          Eigen::Vector3d MapWriter<value_type>::get_dec ()
           {
             assert (type == DEC);
-            Eigen::Vector3 value;
+            Eigen::Vector3d value;
             buffer.index(3) = 0; value[0] = buffer.value();
             buffer.index(3)++;   value[1] = buffer.value();
             buffer.index(3)++;   value[2] = buffer.value();
@@ -469,7 +469,7 @@ namespace MR {
           }
 
         template <typename value_type>
-          void MapWriter<value_type>::set_dec (const Eigen::Vector3& value)
+          void MapWriter<value_type>::set_dec (const Eigen::Vector3d& value)
           {
             assert (type == DEC);
             buffer.index(3) = 0; buffer.value() = value[0];
