@@ -1,4 +1,4 @@
-/* Copyright (c) 2008-2021 the MRtrix3 contributors.
+/* Copyright (c) 2008-2022 the MRtrix3 contributors.
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -147,7 +147,7 @@ namespace MR
             bool operator() (const DWI::Tractography::Streamline<>& tck,
                              vector<index_type>& out) const
             {
-              using direction_type = Eigen::Vector3;
+              using direction_type = Eigen::Vector3d;
               using SetVoxelDir = DWI::Tractography::Mapping::SetVoxelDir;
 
               SetVoxelDir in;
