@@ -1,4 +1,4 @@
-/* Copyright (c) 2008-2021 the MRtrix3 contributors.
+/* Copyright (c) 2008-2022 the MRtrix3 contributors.
  *
  * This Source Code Form is subject to the terms of the Mozilla Public
  * License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -47,7 +47,7 @@ namespace MR
 
         // For speed, want the vertex data to be in voxel positions
         Mesh mesh;
-        vector<Eigen::Vector3> polygon_normals;
+        vector<Eigen::Vector3d> polygon_normals;
 
         // For every edge voxel, stores those polygons that may intersect the voxel
         using Vox2Poly = std::map< Vox, vector<size_t> >;
@@ -126,13 +126,13 @@ namespace MR
                 mesh.load_quad_vertices (vertices, poly_index - mesh.num_triangles());
 
               // Test whether or not the two objects can be separated via projection onto an axis
-              auto separating_axis = [&] (const Eigen::Vector3& axis) -> bool {
+              auto separating_axis = [&] (const Eigen::Vector3d& axis) -> bool {
                 default_type voxel_low  =  std::numeric_limits<default_type>::infinity();
                 default_type voxel_high = -std::numeric_limits<default_type>::infinity();
                 default_type poly_low   =  std::numeric_limits<default_type>::infinity();
                 default_type poly_high  = -std::numeric_limits<default_type>::infinity();
 
-                static const Eigen::Vector3 voxel_offsets[8] = { { -0.5, -0.5, -0.5 },
+                static const Eigen::Vector3d voxel_offsets[8] = { { -0.5, -0.5, -0.5 },
                                                                  { -0.5, -0.5,  0.5 },
                                                                  { -0.5,  0.5, -0.5 },
                                                                  { -0.5,  0.5,  0.5 },
@@ -142,7 +142,7 @@ namespace MR
                                                                  {  0.5,  0.5,  0.5 } };
 
                 for (size_t i = 0; i != 8; ++i) {
-                  const Eigen::Vector3 v (vox.matrix().cast<default_type>() + voxel_offsets[i]);
+                  const Eigen::Vector3d v (vox.matrix().cast<default_type>() + voxel_offsets[i]);
                   const default_type projection = axis.dot (v);
                   voxel_low  = std::min (voxel_low,  projection);
                   voxel_high = std::max (voxel_high, projection);
@@ -163,7 +163,7 @@ namespace MR
               //   All cross-products between voxel and polygon edges
               //   Polygon normal
               for (size_t i = 0; i != 3; ++i) {
-                Eigen::Vector3 axis (0.0, 0.0, 0.0);
+                Eigen::Vector3d axis (0.0, 0.0, 0.0);
                 axis[i] = 1.0;
                 if (separating_axis (axis))
                   return false;
@@ -228,7 +228,7 @@ namespace MR
               for (adj_voxel[1] = centre_voxel[1]-1; adj_voxel[1] <= centre_voxel[1]+1; ++adj_voxel[1]) {
                 for (adj_voxel[0] = centre_voxel[0]-1; adj_voxel[0] <= centre_voxel[0]+1; ++adj_voxel[0]) {
                   if (!is_out_of_bounds (H, adj_voxel) && (adj_voxel - centre_voxel).any()) {
-                    const Eigen::Vector3 offset (adj_voxel.cast<default_type>().matrix() - mesh.vert(i));
+                    const Eigen::Vector3d offset (adj_voxel.cast<default_type>().matrix() - mesh.vert(i));
                     const default_type dp_normal = offset.dot (mesh.norm(i));
                     const default_type offset_on_plane = (offset - (mesh.norm(i) * dp_normal)).norm();
                     assign_pos_of (adj_voxel).to (sum_distances);
@@ -376,13 +376,13 @@ namespace MR
         class Pipe
         { NOMEMALIGN
           public:
-            Pipe (const Mesh& mesh, const vector<Eigen::Vector3>& polygon_normals) :
+            Pipe (const Mesh& mesh, const vector<Eigen::Vector3d>& polygon_normals) :
                 mesh (mesh),
                 polygon_normals (polygon_normals)
 
             {
               // Generate a set of points within this voxel that need to be tested individually
-              offsets_to_test.reset(new vector<Eigen::Vector3>());
+              offsets_to_test.reset(new vector<Eigen::Vector3d>());
               offsets_to_test->reserve (pve_nsamples);
               for (size_t x_idx = 0; x_idx != pve_os_ratio; ++x_idx) {
                 const default_type x = -0.5 + ((default_type(x_idx) + 0.5) / default_type(pve_os_ratio));
@@ -404,7 +404,7 @@ namespace MR
               size_t inside_mesh_count = 0;
               for (vector<Vertex>::const_iterator i_p = offsets_to_test->begin(); i_p != offsets_to_test->end(); ++i_p) {
                 Vertex p (*i_p);
-                p += Eigen::Vector3 (voxel[0], voxel[1], voxel[2]);
+                p += Eigen::Vector3d (voxel[0], voxel[1], voxel[2]);
 
                 default_type best_min_edge_distance_on_plane = -std::numeric_limits<default_type>::infinity();
                 bool best_result_inside = false;
@@ -412,7 +412,7 @@ namespace MR
 
                 // Only test against those polygons that are near this voxel
                 for (vector<size_t>::const_iterator polygon_index = in.second.begin(); polygon_index != in.second.end(); ++polygon_index) {
-                  const Eigen::Vector3& n (polygon_normals[*polygon_index]);
+                  const Eigen::Vector3d& n (polygon_normals[*polygon_index]);
 
                   const size_t polygon_num_vertices = (*polygon_index < mesh.num_triangles()) ? 3 : 4;
                   VertexList v;
@@ -516,9 +516,9 @@ namespace MR
 
           private:
             const Mesh& mesh;
-            const vector<Eigen::Vector3>& polygon_normals;
+            const vector<Eigen::Vector3d>& polygon_normals;
 
-            std::shared_ptr<vector<Eigen::Vector3>> offsets_to_test;
+            std::shared_ptr<vector<Eigen::Vector3d>> offsets_to_test;
 
         };
 
